@@ -4,7 +4,7 @@
 * acp_common [Português]
 *
 * @package language
-* @version 1.0.6
+* @version 1.0.9
 * @Traduzido por: http://phpbbportugal.com - segundo as normas do Acordo Ortográfico
 * @copyright (c) 2005 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
@@ -51,7 +51,7 @@ $lang = array_merge($lang, array(
 	'ACP_BAN'						=> 'Expulsões',
 	'ACP_BAN_EMAILS'				=> 'Expulsar Emails',
 	'ACP_BAN_IPS'					=> 'Expulsar IPs',
-	'ACP_BAN_USERNAMES'				=> 'Expulsar Nomes de Utilizadores',
+	'ACP_BAN_USERNAMES'				=> 'Expulsar Utilizadores',
 	'ACP_BBCODES'					=> 'BBCodes',
 	'ACP_BOARD_CONFIGURATION'		=> 'Configuração Geral',
 	'ACP_BOARD_FEATURES'			=> 'Ferramentas do Fórum',
@@ -293,7 +293,7 @@ $lang = array_merge($lang, array(
 
 // PHP info 
 $lang = array_merge($lang, array( 
-	'ACP_PHP_INFO_EXPLAIN'			=> 'Esta página mostra informações da versão do PHP instalada neste servidor, incluindo detalhes dos módulos carregados, variáveis disponíveis e as configurações padrão. Esta informação pode ser necessária quando forem detetados erros. Alguns servidores podem limitar, por medida de segurança, as informações exibidas. Mantenha estas informações reservadas exceto quando questionado pela <a href="https://www.phpbb.com/about/">Equipa Oficial de Membros</a> no Fórum de Suporte.',
+	'ACP_PHP_INFO_EXPLAIN'			=> 'Esta página mostra informações da versão do PHP instalada neste servidor, incluindo detalhes dos módulos carregados, variáveis disponíveis e as configurações padrão. Esta informação pode ser necessária quando forem detetados erros. Alguns servidores podem limitar, por medida de segurança, as informações exibidas. Mantenha estas informações reservadas exceto quando questionado pela <a href="https://www.phpbb.com/about/team/">membros da equipa oficial</a> no Fórum de Suporte.',
 
 	'NO_PHPINFO_AVAILABLE'			=> 'As informações do PHP não podem ser determinadas. O Phpinfo() foi desativado por medidas de segurança.',
 )); 
@@ -317,9 +317,9 @@ $lang = array_merge($lang, array(
 
 // Index page 
 $lang = array_merge($lang, array( 
-	'ADMIN_INTRO'					=> 'Obrigado por usar o <b>phpBB3</b> no seu Fórum. Esta página apresenta as Estatísticas Gerais do Fórum.<br /> À esquerda encontra os menus de acesso ao <b>Painel de Administração</b>. Cada um deles contém instruções de configuração.',
+	'ADMIN_INTRO'					=> 'Obrigado por usar o phpBB3 no seu Fórum. Esta página apresenta as Estatísticas Gerais do Fórum. À esquerda encontra os menus de acesso ao Painel de Administração. Cada um deles contém instruções de configuração.',
 	'ADMIN_LOG'						=> 'Registos da ações dos Administradores',
-	'ADMIN_LOG_INDEX_EXPLAIN'		=> 'Este registo mostra as últimas cinco ações dos Administradores.<br />Uma cópia completa do registo está disponível no item apropriado do Menu ou seguindo o atalho abaixo.',
+	'ADMIN_LOG_INDEX_EXPLAIN'		=> 'Este registo mostra as últimas cinco ações dos Administradores. Uma cópia completa do registo está disponível no item apropriado do Menu ou seguindo o atalho abaixo.',
 	'AVATAR_DIR_SIZE'				=> 'Tamanho da diretoria dos avatares',
 
 	'BOARD_STARTED'					=> 'Data de criação do Fórum',
@@ -392,7 +392,7 @@ $lang = array_merge($lang, array(
 	'VIEW_INACTIVE_USERS'			=> 'Ver Utilizadores Inativos',
 
 	'WELCOME_PHPBB'					=> 'Bem-vindo ao phpBB',
-	'WRITABLE_CONFIG'				=> 'O seu ficheiro de configuração (config.php) encontra-se universalmente configurável. É altamente recomendável que modifique as Permissões do ficheiro para 640 ou 644 (leia: <a href="http://pt.wikipedia.org/wiki/Chmod" rel="external">chmod</a>).',
+	'WRITABLE_CONFIG'				=> 'O seu ficheiro de configuração (config.php) encontra-se universalmente configurável. É altamente recomendável que modifique as Permissões do ficheiro para 640 ou 644 (leia: <a href="http://en.wikipedia.org/wiki/Chmod" rel="external">chmod</a> 640 config.php).',
 )); 
 
 // Inactive Users
@@ -616,7 +616,7 @@ $lang = array_merge($lang, array(
 	'LOG_LANGUAGE_PACK_INSTALLED'			=> '<strong>Pacotes de idiomas instalados</strong><br />» %s',
 	'LOG_LANGUAGE_PACK_UPDATED'				=> '<strong>Detalhes do Pacote de idiomas atualizados</strong><br />» %s',
 	'LOG_LANGUAGE_FILE_REPLACED'			=> '<strong>Ficheiros de Linguagem substituídos</strong><br />» %s',
-	'LOG_LANGUAGE_FILE_SUBMITTED'			=> '<strong>Ficheiro de Linguagem enviado e armazenado na pasta <b>\store</b></strong><br />» %s',
+	'LOG_LANGUAGE_FILE_SUBMITTED'			=> '<strong>Ficheiro de Linguagem enviado e armazenado na pasta \store</strong><br />» %s',
 
 	'LOG_MASS_EMAIL'						=> '<strong>Enviar Email em Massa</strong><br />» %s',
 
