@@ -4,7 +4,7 @@
 * acp_permissions [Português]
 *
 * @package language
-* @version 1.0.6
+* @version 1.0.9
 * @Traduzido por: http://phpbbportugal.com - segundo as normas do Acordo Ortográfico
 * @copyright (c) 2005 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
@@ -54,7 +54,7 @@ $lang = array_merge($lang, array(
 	 
 		<br /> 
 
-		<p><b>Para mais informações sobre a configuração e a Gestão de Permissões no phpBB3, veja o <a href="https://www.phpbb.com/support/documentation/3.0/quickstart/quick_permissions.html" onclick="this.target=\'_blank\';" title="Abrir numa janela nova">Capítulo 1.5 do Guia de Inicialização Rápida</a></b>.</p> 
+		<p>Para mais informações sobre a configuração e a Gestão de Permissões no phpBB3, veja o <a href="https://www.phpbb.com/support/documentation/3.0/quickstart/quick_permissions.html">Chapter 1.5 of our Quick Start Guide</a>.</p>
 	',
 
 	'ACL_NEVER'				=> 'Nunca',
@@ -185,11 +185,11 @@ $lang = array_merge($lang, array(
 	'ROLE_USER_NEW_MEMBER'			=> 'Características do Utilizador Registado Recentemente',
 	
 	'ROLE_DESCRIPTION_ADMIN_FORUM'			=> 'Tem acesso às funções de Gestão e Permissões de Fóruns.',
-	'ROLE_DESCRIPTION_ADMIN_FULL'			=> 'Tem acesso a todas as funções administrativas neste Fórum. <b>Recomendado para Fundadores</b>.',
+	'ROLE_DESCRIPTION_ADMIN_FULL'			=> 'Tem acesso a todas as funções administrativas neste Fórum. Recomendado para Fundadores.',
 	'ROLE_DESCRIPTION_ADMIN_STANDARD'		=> 'Tem acesso às funções administrativas, mas não às relacionadas com o Servidor ou o Sistema.',
 	'ROLE_DESCRIPTION_ADMIN_USERGROUP'		=> 'Tem acesso às funções de administração de Utilizadores e Grupos. Pode alterar permissões, configurações, administrar expulsões e classificações.',
 	'ROLE_DESCRIPTION_FORUM_BOT'			=> 'Acesso recomendado a Motores de Busca.',
-	'ROLE_DESCRIPTION_FORUM_FULL'			=> 'Pode utilizar todas as Funções do Fórum. Criar Anúncios e Tópicos Fixos e ignorar o limite de mensagens. <b>Não recomendado a Utilizadores Normais</b>.',
+	'ROLE_DESCRIPTION_FORUM_FULL'			=> 'Pode utilizar todas as Funções do Fórum. Criar Anúncios e Tópicos Fixos e ignorar o limite de mensagens. Não recomendado a Utilizadores Normais.',
 	'ROLE_DESCRIPTION_FORUM_LIMITED'		=> 'Pode utilizar algumas funções do Fórum. Não pode anexar ficheiros ou utilizar ícones nas Mensagens.',
 	'ROLE_DESCRIPTION_FORUM_LIMITED_POLLS'	=> 'Pode utilizar algumas funções do Fórum. Não pode anexar ficheiros ou utilizar ícones nas mensagens. Pode criar Votações.',
 	'ROLE_DESCRIPTION_FORUM_NOACCESS'		=> 'Não pode ver o Fórum (invisível).',
@@ -197,17 +197,17 @@ $lang = array_merge($lang, array(
 	'ROLE_DESCRIPTION_FORUM_POLLS'			=> 'Pode utilizar a maior parte das Funções do Fórum, incluindo os Anexos. Não pode bloquear ou eliminar os próprios Tópicos. Pode criar votações.',
 	'ROLE_DESCRIPTION_FORUM_READONLY'		=> 'Pode ver e ler o Fórum. Não pode criar Tópicos nem responder às Mensagens.',
 	'ROLE_DESCRIPTION_FORUM_STANDARD'		=> 'Pode utilizar a maior parte das Funções do Fórum, incluindo os Anexos. Não pode bloquear ou eliminar os próprios Tópicos, e criar votações.',
-	'ROLE_DESCRIPTION_FORUM_NEW_MEMBER'		=> 'A função dos membros do Grupo Especial de Utilizadores Registados Recentemente. Contém permissões <b>Nunca</b> para bloquear recursos aos novos utilizadores.',
+	'ROLE_DESCRIPTION_FORUM_NEW_MEMBER'		=> 'A função dos membros do Grupo Especial de Utilizadores Registados Recentemente. Contém permissões Nunca para bloquear recursos aos novos utilizadores.',
 	'ROLE_DESCRIPTION_MOD_FULL'				=> 'Pode utilizar todas as funções de Moderação. Pode fazer expulsões.',
 	'ROLE_DESCRIPTION_MOD_QUEUE'			=> 'Pode utilizar algumas das funções de Moderação. Pode moderar fóruns, validar e editar mensagens.',
 	'ROLE_DESCRIPTION_MOD_SIMPLE'			=> 'Pode utilizar as Funções de Moderação dos Tópicos. Não pode fazer advertências ou moderar fóruns.',
 	'ROLE_DESCRIPTION_MOD_STANDARD'			=> 'Pode utilizar a maioria das funções de Moderação. Não pode fazer expulsões ou alterar o autor das mensagens.',
-	'ROLE_DESCRIPTION_USER_FULL'			=> 'Pode utilizar todas as funções do Utilizador, incluindo a alteração do nome do utilizador ou ignorar o limite de mensagens. <b>Usar só em situações especiais</b>.',
+	'ROLE_DESCRIPTION_USER_FULL'			=> 'Pode utilizar todas as funções do Utilizador, incluindo a alteração do nome do utilizador ou ignorar o limite de mensagens. Usar só em situações especiais.',
 	'ROLE_DESCRIPTION_USER_LIMITED'			=> 'Pode utilizar algumas das funções do Utilizador. Não pode usar anexos, emails ou mensagens urgentes.',
 	'ROLE_DESCRIPTION_USER_NOAVATAR'		=> 'Pode utilizar algumas das funções do Utilizador. Não pode usar Avatar.',
 	'ROLE_DESCRIPTION_USER_NOPM'			=> 'Pode utilizar algumas das funções do Utilizador. Não pode usar Mensagens Privadas.',
 	'ROLE_DESCRIPTION_USER_STANDARD'		=> 'Pode utilizar a maior parte das funções do Utilizador. Não pode alterar o nome do utilizador ou ignorar o limite de mensagens.',
-	'ROLE_DESCRIPTION_USER_NEW_MEMBER'		=> 'A função dos membros do Grupo Especial de Utilizadores Registados Recentemente. Contém permissões <b>Nunca</b> para bloquear recursos aos novos utilizadores.',
+	'ROLE_DESCRIPTION_USER_NEW_MEMBER'		=> 'A função dos membros do Grupo Especial de Utilizadores Registados Recentemente. Contém permissões Nunca para bloquear recursos aos novos utilizadores.',
 
 	'ROLE_DESCRIPTION_EXPLAIN'				=> 'Pode fazer uma pequena descrição das tarefas atribuídas à categoria. O Texto será mostrado nas Permissões.',
 	'ROLE_DESCRIPTION_LONG'					=> 'A Descrição da tarefa é muito grande. Por Favor, limite seu texto a 4000 caracteres.',
