@@ -4,13 +4,12 @@
 * acp_posting [Português]
 *
 * @package language
-* @version 1.0.6
+* @version 1.0.9
 * @Traduzido por: http://phpbbportugal.com - segundo as normas do Acordo Ortográfico
 * @copyright (c) 2005 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 * 
 */
-
 /**
 * DO NOT CHANGE
 */
@@ -39,7 +38,7 @@ if (empty($lang) || !is_array($lang))
 // BBCodes
 // Note to translators: you can translate everything but what's between { and }
 $lang = array_merge($lang, array(
-	'ACP_BBCODES_EXPLAIN'			=> 'BBCode (Bulletin Board Code) é uma linguagem originalmente desenvolvida para phpBB. Permite configurar o que é, e como é exibido.<br /> Aqui é possível adicionar, editar e apagar BBCodes.',
+	'ACP_BBCODES_EXPLAIN'			=> 'BBCode (Bulletin Board Code) é uma linguagem originalmente desenvolvida para phpBB. Permite configurar o que é, e como é exibido. Aqui é possível adicionar, editar e apagar BBCodes.',
 	'ADD_BBCODE'					=> 'Adicionar novo BBCode',
 	'BBCODE_DANGER'					=> 'O BBCode que está a tentar adicionar parece usar um {TEXT} dentro de um atributo de HTML. Esta é uma possível questão de segurança XSS. Em alternativa, tente usar o mais restritivo {SimpleText} ou {INTTEXT}. Só prossiga se compreende os riscos de segurança envolvidos e se considera inevitável o uso de {TEXT}.',
 	'BBCODE_DANGER_PROCEED'			=> 'Continuar', //'I understand the risk',
@@ -237,7 +236,7 @@ $lang = array_merge($lang, array(
 // Disallow Usernames 
 $lang = array_merge($lang, array( 
 	'ACP_DISALLOW_EXPLAIN'			=> 'Aqui pode gerir os nomes cuja utilização é proibida. Utilize o asterisco (*) para facilitar a construção de nomes.',
-	'ADD_DISALLOW_EXPLAIN'			=> 'Introduza o nome que deseja proibir. <br />Use os asteriscos (*) cuidadosamente.',
+	'ADD_DISALLOW_EXPLAIN'			=> 'Introduza o nome que deseja proibir. Use os asteriscos (*) cuidadosamente.',
 	'ADD_DISALLOW_TITLE'			=> 'Adicionar um Nome Proibido',
 
 	'DELETE_DISALLOW_EXPLAIN'		=> 'Aqui pode eliminar uma proibição, selecionando na lista o nome cuja proibição pretende anular, clicando de seguida em enviar.',
