@@ -4,7 +4,7 @@
 * acp_styles [Português]
 *
 * @package language
-* @version 1.0.6
+* @version 1.0.9
 * @Traduzido por: http://phpbbportugal.com - segundo as normas do Acordo Ortográfico
 * @copyright (c) 2005 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
@@ -38,7 +38,7 @@ if (empty($lang) || !is_array($lang))
 
 $lang = array_merge($lang, array(
 	'ACP_IMAGESETS_EXPLAIN'			=> 'Conjuntos de Imagens são todos os botões, Fórum, pastas, etc. e outras imagens não especificamente usadas pelo Estilo do Fórum. Aqui pode editar, exportar ou apagar um Conjunto de Imagens existente e importar ou ativar novos Conjuntos.',
-	'ACP_STYLES_EXPLAIN'			=> 'Aqui pode gerir os Estilos do Fórum. Um Estilo é formado por um Template, um Tema e Conjunto de Imagens. Pode alterar os Estilos, apagar, desativar, reativar, criar ou importar novos Estilos. Pode usar a Função Prever para pré-visualizar o novo Estilo. O Estilo Padrão está assinalado com um asterisco (*). Está indicado em cada um dos Estilos instalados o número de Utilizadores que o está a usar.<br />As modificações nos Estilos dos Utilizadores não se reflete aqui no <b>Painel de Administração</b>.',
+	'ACP_STYLES_EXPLAIN'			=> 'Aqui pode gerir os Estilos do Fórum. Um Estilo é formado por um Template, um Tema e Conjunto de Imagens. Pode alterar os Estilos, apagar, desativar, reativar, criar ou importar novos Estilos. Pode usar a Função Prever para pré-visualizar o novo Estilo. O Estilo Padrão está assinalado com um asterisco (*). Está indicado em cada um dos Estilos instalados o número de Utilizadores que o está a usar. As modificações nos Estilos dos Utilizadores não se reflete aqui no Painel de Administração.',
 	'ACP_TEMPLATES_EXPLAIN'			=> 'Um Template é o código usado para gerar o visual do Fórum. Pode alterar, apagar, desativar, ativar, criar ou importar novos Templates. Também pode modificar o código do Template usado para gerar BBCode.',
 	'ACP_THEMES_EXPLAIN'			=> 'Aqui pode criar, instalar, editar, apagar e exportar Temas. Um Tema é a combinação de cores e imagens que são usadas nos Templates para definir o visual básico do Fórum. As opções disponíveis dependem da configuração do servidor e da instalação do phpBB, consulte o manual para mais informações. Na criação de novos Temas é opcional o uso de um Tema já existente.',
 	'ADD_IMAGESET'					=> 'Criar Conjunto de Imagens',
