@@ -4,7 +4,7 @@
 * common [Português]
 *
 * @package language
-* @version 1.0.6
+* @version 1.0.9
 * @Traduzido por: http://phpbbportugal.com - segundo as normas do Acordo Ortográfico
 * @copyright (c) 2005 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
@@ -41,7 +41,7 @@ if (empty($lang) || !is_array($lang))
 //
 
 $lang = array_merge($lang, array(
-	'TRANSLATION_INFO'					=> 'Traduzido por <a href="http://phpbbportugal.com" title="phpBB Portugal"><b>phpBB Portugal</b></a>',
+	'TRANSLATION_INFO'					=> 'Traduzido por phpBB Portugal',
 	'DIRECTION'							=> 'ltr',
 	'DATE_FORMAT'						=> '|d M Y|',	// 01 Jan 2007 (with Relative days enabled) 
 	'USER_LANG'							=> 'pt',
@@ -89,9 +89,10 @@ $lang = array_merge($lang, array(
 	'AVATAR_PARTIAL_UPLOAD'				=> 'O Ficheiro foi parcialmente enviado.',
 	'AVATAR_PHP_SIZE_NA'				=> 'O Ficheiro do Avatar é demasiado grande.<br />Não foi possível determinar o tamanho máximo definido pelo PHP no php.ini.',
 	'AVATAR_PHP_SIZE_OVERRUN'			=> 'O Ficheiro do Avatar é demasiado grande, sendo o máximo permitido de envio %1$d %2$s.<br />Por favor, note que isto é definido no php.ini e não pode ser alterado.',
+	'AVATAR_REMOTE_UPLOAD_TIMEOUT'		=> 'O avatar especificado não pôde ser carregado porque o pedido excedeu o tempo limite.',
 	'AVATAR_URL_INVALID'				=> 'A URL que especificou é inválida.',
 	'AVATAR_URL_NOT_FOUND'				=> 'O Ficheiro indicado não foi encontrado.',
-	'AVATAR_WRONG_FILESIZE'				=> 'O tamanho do Avatar deve estar entre 0 e %1d %2s.',
+	'AVATAR_WRONG_FILESIZE'				=> 'O tamanho do Avatar deve estar entre 0 e %1$d %2$s.',
 	'AVATAR_WRONG_SIZE'					=> 'O Avatar submetido tem %5$d pixels de largura e %6$d pixels de altura. Os Avatares devem ter %1$d pixels de largura e %2$d pixels de altura, mas não podem ser maiores do que %3$d pixels de largura e %4$d pixels de altura.',
 	
 	'BACK_TO_TOP'						=> 'Topo',
@@ -102,9 +103,9 @@ $lang = array_merge($lang, array(
 	'BBCODE_GUIDE'						=> 'Guia BBCode',
 	'BCC'								=> 'Bc',
 	'BIRTHDAYS'							=> 'Aniversariantes',
-	'BOARD_BAN_PERM'					=> 'Foi expulso <b>permanentemente</b> deste Fórum.<br /><br />Por favor, contate o %2$sAdministrador%3$s para mais informações.',
-	'BOARD_BAN_REASON'					=> 'Razão da expulsão: <b>%s</b>',
-	'BOARD_BAN_TIME'					=> 'Foi expulso deste Fórum até <b>%1$s</b>.<br /><br />Por favor, contate o %2$sAdministrador%3$s para mais informações.',
+	'BOARD_BAN_PERM'					=> 'Foi expulso permanentemente deste Fórum.<br /><br />Por favor, contate o %2$sAdministrador%3$s para mais informações.',
+	'BOARD_BAN_REASON'					=> 'Razão da expulsão: %s',
+	'BOARD_BAN_TIME'					=> 'Foi expulso deste Fórum até %1$s.<br /><br />Por favor, contate o %2$sAdministrador%3$s para mais informações.',
 	'BOARD_DISABLE'						=> 'Este Fórum está indisponível no momento.',
 	'BOARD_DISABLED'					=> 'Este Fórum está atualmente desativado.',
 	'BOARD_UNAVAILABLE'					=> 'Este Fórum não se encontra disponível neste momento. Por Favor, tente novamente mais tarde.',
@@ -163,7 +164,7 @@ $lang = array_merge($lang, array(
 	'EMAIL_ADDRESS'						=> 'Endereço de email',
 	'EMAIL_INVALID_EMAIL'				=> 'O endereço de email que introduziu é inválido.',
 	'EMAIL_SMTP_ERROR_RESPONSE'			=> 'Ocorreu um problema ao enviar o email na <strong>Linha %1$s</strong>. Erro: %2$s.',
-	'EMPTY_SUBJECT'						=> 'Quando se envia uma mensagem, deve ser especificado um <strong>ASSUNTO</strong>.',
+	'EMPTY_SUBJECT'						=> 'Quando se envia uma mensagem, deve ser especificado um ASSUNTO.',
 	'EMPTY_MESSAGE_SUBJECT'				=> 'Precisa especificar um assunto quando escrever uma nova mensagem.',
 	'ENABLED'							=> 'Ativado',
 	'ENCLOSURE'							=> 'Documento anexo',
@@ -178,7 +179,7 @@ $lang = array_merge($lang, array(
 	'ERR_WRONG_PATH_TO_PHPBB'			=> 'O local do script phpBB indicado parece não ser válido.',
 	'EXPAND_VIEW'						=> 'Ver mais detalhes',
 	'EXTENSION'							=> 'Extensão',
-	'EXTENSION_DISABLED_AFTER_POSTING'	=> 'A extensão <b>%s</b> foi desativada e não pode ser exibida.',
+	'EXTENSION_DISABLED_AFTER_POSTING'	=> 'A extensão %s foi desativada e não pode ser exibida.',
 
 	'FAQ'								=> 'FAQ',
 	'FAQ_EXPLAIN'						=> 'Questões Mais Frequentes',
@@ -281,7 +282,7 @@ $lang = array_merge($lang, array(
 	'INFORMATION'						=> 'Informação',
 	'INTERESTS'							=> 'Interesses',
 	'INVALID_DIGEST_CHALLENGE'			=> 'Desafio de Sumário Inválido.',
-	'INVALID_EMAIL_LOG'					=> '<b>%s</b> é um endereço de email possivelmente incorreto?',
+	'INVALID_EMAIL_LOG'					=> '%s é um endereço de email possivelmente incorreto?',
 	'IP'								=> 'IP',
 	'IP_BLACKLISTED'					=> 'O Seu endereço de IP %1$s foi expulso porque está na lista negra. Para mais detalhes leia <a href="%2$s">%2$s</a>.',
 
@@ -300,7 +301,7 @@ $lang = array_merge($lang, array(
 	'LDAP_NO_LDAP_EXTENSION'			=> 'Extensão LDAP não disponível.',
 	'LDAP_NO_SERVER_CONNECTION'			=> 'Não foi possível ligar-se ao servidor LDAP.',
 	'LDAP_SEARCH_FAILED'				=> 'Ocorreu um erro durante a pesquisa na pasta LDAP.',
-	'LEGEND'							=> '<b>Legenda</b>',
+	'LEGEND'							=> 'Legenda',
 	'LOCATION'							=> 'Localização',
 	'LOCK_POST'							=> 'Bloquear Mensagem',
 	'LOCK_POST_EXPLAIN'					=> 'Edição Prévia',
@@ -315,7 +316,7 @@ $lang = array_merge($lang, array(
 	'LOGIN_ERROR_PASSWORD_CONVERT'		=> 'Não foi possível converter a sua Senha ao atualizar este Fórum. Por favor peça uma %snova senha%s. Se continuar com problemas, contate um %sAdministrador do Fórum%s.',
 	'LOGIN_ERROR_USERNAME'				=> 'Especificou um nome de Utilizador incorreto. Confirme o seu nome de Utilizador e tente novamente. Se continuar com problemas, por favor, contate um %sAdministrador do Fórum%s.',
 	'LOGIN_FORUM'						=> 'Para ver ou enviar mensagens neste Fórum deve inserir a Senha.',
-	'LOGIN_INFO'						=> 'O acesso completo ao <b>Fórum</b> necessita dum Registo que demora apenas alguns segundos. <br /> Antes de se Registar leia:<br /><b>- FAQ</b><br /><b>- Condições de Utilização</b><br /><b>- Política de Privacidade</b><br /><br /> <b>Respeite as regras do Fórum</b>.',
+	'LOGIN_INFO'						=> 'O acesso completo ao Fórum necessita dum Registo que demora apenas alguns segundos. Antes de se Registar leia: - FAQ - Condições de Utilização - Política de Privacidade Respeite as regras do Fórum.',
 	'LOGIN_VIEWFORUM'					=> 'Para ver o conteúdo completo deste Fórum é necessário estar ligado.',
 	'LOGIN_EXPLAIN_EDIT'				=> 'Para editar Mensagens neste Fórum tem de estar registado e ligado.',
 	'LOGIN_EXPLAIN_VIEWONLINE'			=> 'Para aparecer na lista tem de estar registado e ligado.',
@@ -342,16 +343,19 @@ $lang = array_merge($lang, array(
 	'MODERATE'							=> 'Moderado',
 	'MODERATOR'							=> 'Moderador',
 	'MODERATORS'						=> 'Moderadores',
+	'MODULE_NOT_ACCESS'					=> 'Módulo não encontrado',
+	'MODULE_NOT_FIND'					=> 'O Módulo %s não foi encontrado',
+	'MODULE_FILE_INCORRECT_CLASS'		=> 'O ficheiro do Módulo %s não tem a classe correta [%s]',
 	'MONTH'								=> 'Mês',
 	'MOVE'								=> 'Mover',
 	'MSNM'								=> 'MSM/WLM',
 
 	'NA'								=> 'N/A',
-	'NEWEST_USER'						=> '<b>%s</b> é o(a) nosso(a) Utilizador(a) mais recente. Bem-vindo(a) ao <b>Fórum</b>',
+	'NEWEST_USER'						=> '%s é o(a) nosso(a) Utilizador(a) mais recente. Bem-vindo(a) ao Fórum',
 	'NEW_MESSAGE'						=> 'Nova Mensagem',
 	'NEW_MESSAGES'						=> 'Novas Mensagens',
-	'NEW_PM'							=> '<b>%d</b> mensagem privada nova',
-	'NEW_PMS'							=> '<b>%d</b> mensagens privadas novas',
+	'NEW_PM'							=> '%d mensagem privada nova',
+	'NEW_PMS'							=> '%d mensagens privadas novas',
 	'NEW_POST'							=> 'Nova Mensagem',   // Not used anymore
 	'NEW_POSTS'							=> 'Novas Mensagens',   // Not used anymore
 	'NEXT'								=> 'Próximo',      // Used in pagination
@@ -400,7 +404,7 @@ $lang = array_merge($lang, array(
 	'NO_TOPIC_FORUM'					=> 'Este Tópico ou Fórum não existem.',
 	'NO_TOPICS'							=> 'Não há mensagens ou Tópicos neste Fórum.',
 	'NO_TOPICS_TIME_FRAME'				=> 'Não há Tópicos neste Fórum no prazo selecionado.',
-	'NO_UNREAD_PM'						=> '<b>0</b> Mensagem não lidas',
+	'NO_UNREAD_PM'						=> '0 Mensagem não lidas',
 	'NO_UNREAD_POSTS'					=> 'Não há novas mensagens',
 	'NO_UPLOAD_FORM_FOUND'				=> 'O envio do ficheiro foi iniciado, mas nenhuma forma de envio válida foi encontrada.',
 	'NO_USER'							=> 'Este Utilizador não existe.',
@@ -418,12 +422,12 @@ $lang = array_merge($lang, array(
 	'OFFLINE'							=> 'Desligado',
 	'ONLINE'							=> 'Ligado',
 	'ONLINE_BUDDIES'					=> 'Amigos ligados',
-	'ONLINE_USERS_TOTAL'				=> 'No total há <b>%d</b> Utilizadores ligados :: ',
-	'ONLINE_USERS_ZERO_TOTAL'			=> 'No total há <b>0</b> Utilizadores ligados :: ',
-	'ONLINE_USER_TOTAL'					=> 'No total há <b>%d</b> Utilizador ligado :: ',
+	'ONLINE_USERS_TOTAL'				=> 'No total há %d Utilizadores ligados :: ',
+	'ONLINE_USERS_ZERO_TOTAL'			=> 'No total há 0 Utilizadores ligados :: ',
+	'ONLINE_USER_TOTAL'					=> 'No total há %d Utilizador ligado :: ',
 	'OPTIONS'							=> 'Opções',
 
-	'PAGE_OF'							=> 'Página <b>%1$d</b> de <b>%2$d</b>',
+	'PAGE_OF'							=> 'Página %1$d de %2$d',
 	'PASSWORD'							=> 'Senha',
 	'PIXEL'								=> 'px',
 	'PLAY_QUICKTIME_FILE'				=> 'Reproduzir ficheiro Quicktime',
@@ -440,7 +444,7 @@ $lang = array_merge($lang, array(
 	'POSTS'								=> 'Mensagens',
 	'POSTS_UNAPPROVED'					=> 'Pelo menos uma mensagem neste Tópico não foi aprovada.',
 	'POST_BY_AUTHOR'					=> 'por',
-	'POST_BY_FOE'						=> 'Está mensagem foi enviada por <b>%1$s</b> que está na sua lista de ignorados. Para mostrar a mensagem clique %2$sAqui%3$s.',
+	'POST_BY_FOE'						=> 'Está mensagem foi enviada por %1$s que está na sua lista de ignorados. Para mostrar a mensagem clique %2$sAqui%3$s.',
 	'POST_DAY'							=> '%.2f mensagens por dia',
 	'POST_DETAILS'						=> 'Detalhes da mensagem',
 	'POST_NEW_TOPIC'					=> 'Criar Novo Tópico',
@@ -470,11 +474,11 @@ $lang = array_merge($lang, array(
 	'READING_TOPIC'						=> 'A ler Tópico em %s',
 	'READ_PROFILE'						=> 'Perfil',
 	'REASON'							=> 'Razão',
-	'RECORD_ONLINE_USERS'				=> 'O recorde de utilizadores online foi de <b>%1$s</b> em %2$s',
+	'RECORD_ONLINE_USERS'				=> 'O recorde de utilizadores online foi de %1$s em %2$s',
 	'REDIRECT'							=> 'Redirecionar',
 	'REDIRECTS'							=> 'Total de redirecionamentos',
 	'REGISTER'							=> 'Registe-se',
-	'REGISTERED_USERS'					=> '<b>Membros ligados:</b>',
+	'REGISTERED_USERS'					=> 'Membros ligados:',
 	'REG_USERS_ONLINE'					=> 'Há %d utilizadores registados e ',
 	'REG_USERS_TOTAL'					=> '%d registados, ',
 	'REG_USERS_TOTAL_AND'				=> '%d registados e ',
@@ -505,22 +509,22 @@ $lang = array_merge($lang, array(
 	'FEED_NEWS'							=> 'Novidades',
 	'FEED_TOPICS_ACTIVE'				=> 'Tópicos ativos',
 	'FEED_TOPICS_NEW'					=> 'Novos Tópicos',
-	'RULES_ATTACH_CAN'					=> 'Enviar anexos: <b>Permitido</b>',
-	'RULES_ATTACH_CANNOT'				=> 'Enviar anexos: <b>Proibido</b>',
-	'RULES_DELETE_CAN'					=> 'Apagar Mensagens: <b>Permitido</b>',
-	'RULES_DELETE_CANNOT'				=> 'Apagar Mensagens: <b>Proibido</b>',
-	'RULES_DOWNLOAD_CAN'				=> 'Transferir anexos: <b>Permitido</b>',
-	'RULES_DOWNLOAD_CANNOT'				=> 'Transferir anexos: <b>Proibido</b>',
-	'RULES_EDIT_CAN'					=> 'Editar Mensagens: <b>Permitido</b>',
-	'RULES_EDIT_CANNOT'					=> 'Editar Mensagens: <b>Proibido</b>',
-	'RULES_LOCK_CAN'					=> 'Bloquear Tópicos: <b>Permitido</b>',
-	'RULES_LOCK_CANNOT'					=> 'Bloquear Tópicos: <b>Proibido</b>',
-	'RULES_POST_CAN'					=> 'Criar Tópicos: <b>Permitido</b>',
-	'RULES_POST_CANNOT'					=> 'Criar Tópicos: <b>Proibido</b>',
-	'RULES_REPLY_CAN'					=> 'Responder Tópicos: <b>Permitido</b>',
-	'RULES_REPLY_CANNOT'				=> 'Responder Tópicos: <b>Proibido</b>',
-	'RULES_VOTE_CAN'					=> 'Votar em votações: <b>Permitido</b>',
-	'RULES_VOTE_CANNOT'					=> 'Votar em votações: <b>Proibido</b>',
+	'RULES_ATTACH_CAN'					=> 'Enviar anexos: Permitido',
+	'RULES_ATTACH_CANNOT'				=> 'Enviar anexos: Proibido',
+	'RULES_DELETE_CAN'					=> 'Apagar Mensagens: Permitido',
+	'RULES_DELETE_CANNOT'				=> 'Apagar Mensagens: Proibido',
+	'RULES_DOWNLOAD_CAN'				=> 'Transferir anexos: Permitido',
+	'RULES_DOWNLOAD_CANNOT'				=> 'Transferir anexos: Proibido',
+	'RULES_EDIT_CAN'					=> 'Editar Mensagens: Permitido',
+	'RULES_EDIT_CANNOT'					=> 'Editar Mensagens: Proibido',
+	'RULES_LOCK_CAN'					=> 'Bloquear Tópicos: Permitido',
+	'RULES_LOCK_CANNOT'					=> 'Bloquear Tópicos: Proibido',
+	'RULES_POST_CAN'					=> 'Criar Tópicos: Permitido',
+	'RULES_POST_CANNOT'					=> 'Criar Tópicos: Proibido',
+	'RULES_REPLY_CAN'					=> 'Responder Tópicos: Permitido',
+	'RULES_REPLY_CANNOT'				=> 'Responder Tópicos: Proibido',
+	'RULES_VOTE_CAN'					=> 'Votar em votações: Permitido',
+	'RULES_VOTE_CANNOT'					=> 'Votar em votações: Proibido',
 
 	'SEARCH'							=> 'Pesquisar',
 	'SEARCH_MINI'						=> 'Pesquisar…',
@@ -644,22 +648,22 @@ $lang = array_merge($lang, array(
 	'TOTAL_PM'							=> '1 Mensagem Privada no total',
 	'TOTAL_PMS'							=> 'Tem um total de %d Mensagens Privadas',
 	'TOTAL_POSTS'						=> 'Total de Mensagens',
-	'TOTAL_POSTS_OTHER'					=> 'Total de Mensagens <b>%d</b>',
-	'TOTAL_POSTS_ZERO'					=> 'Total de Mensagens <b>0</b>',
+	'TOTAL_POSTS_OTHER'					=> 'Total de Mensagens %d',
+	'TOTAL_POSTS_ZERO'					=> 'Total de Mensagens 0',
 	'TOPIC_REPORTED'					=> 'Este Tópico foi reportado com sucesso',
-	'TOTAL_TOPICS_OTHER'				=> 'Total de Tópicos <b>%d</b>',
-	'TOTAL_TOPICS_ZERO'					=> 'Total de Tópicos <b>0</b>',
-	'TOTAL_USERS_OTHER'					=> 'Total de Utilizadores <b>%d</b>',
-	'TOTAL_USERS_ZERO'					=> 'Total de Utilizadores <b>0</b>',
+	'TOTAL_TOPICS_OTHER'				=> 'Total de Tópicos %d',
+	'TOTAL_TOPICS_ZERO'					=> 'Total de Tópicos 0',
+	'TOTAL_USERS_OTHER'					=> 'Total de Utilizadores %d',
+	'TOTAL_USERS_ZERO'					=> 'Total de Utilizadores 0',
 	'TRACKED_PHP_ERROR'					=> 'Erros PHP encontrados: %s',
 
-	'UNABLE_GET_IMAGE_SIZE'				=> 'É impossível aceder ao Ficheiro de imagem, porque não é uma imagem válida.',
+	'UNABLE_GET_IMAGE_SIZE'				=> 'Não foi possível determinar as dimensões da imagem. Por favor verifique se o URL que inseriu está correto.',
 	'UNABLE_TO_DELIVER_FILE'			=> 'Incapaz de entregar Ficheiro.',
 	'UNKNOWN_BROWSER'					=> 'Navegador Desconhecido',
 	'UNMARK_ALL'						=> 'Desmarcar todos',
 	'UNREAD_MESSAGES'					=> 'Mensagens não lidas',
-	'UNREAD_PM'							=> '<b>%d</b> mensagem não lida',
-	'UNREAD_PMS'						=> '<b>%d</b> mensagens não lidas',
+	'UNREAD_PM'							=> '%d mensagem não lida',
+	'UNREAD_PMS'						=> '%d mensagens não lidas',
 	'UNREAD_POST'						=> 'Mensagem não lida',
 	'UNREAD_POSTS'						=> 'Mensagens não lidas',
 	'UNWATCH_FORUM_CONFIRM'				=> 'Tem certeza que deseja cancelar a assinatura deste fórum?',
@@ -718,7 +722,7 @@ $lang = array_merge($lang, array(
 	'WATCH_FORUM_DETAILED'				=> 'Tem certeza que deseja subscrever o Fórum “%s”?',
 	'WATCH_TOPIC_CONFIRM'				=> 'Tem certeza que deseja subscrever este Tópico?',
 	'WATCH_TOPIC_DETAILED'				=> 'Tem certeza que deseja subscrever o Tópico “%s”?',
-	'WELCOME_SUBJECT'					=> 'Bem vindo ao Fórum',
+	'WELCOME_SUBJECT'					=> 'Bem vindo ao Fórum %s',
 	'WEBSITE'							=> 'Sítio web',
 	'WHOIS'								=> 'Quem',
 	'WHO_IS_ONLINE'						=> 'Quem está ligado:',
@@ -740,15 +744,15 @@ $lang = array_merge($lang, array(
 	'YOU_NEW_PMS'						=> 'Tem Mensagens Privadas novas.',
 	'YOU_NO_NEW_PM'						=> 'Não tem Mensagens Privadas novas.',
 
-	'datetime'	=> array(
-		'TODAY'							=> 'Hoje',
-		'TOMORROW'						=> 'Amanhã',
-		'YESTERDAY'						=> 'Ontem',
-		'AGO'							=> array(
-			0							=> 'menos de um minuto atrás',
-			1							=> '%d minuto atrás',
-			2							=> '%d minutos atrás',
-			60							=> '1 hora atrás',
+	'datetime'			=> array(
+		'TODAY'		=> 'Hoje',
+		'TOMORROW'	=> 'Amanhã',
+		'YESTERDAY'	=> 'Ontem',
+		'AGO'		=> array(
+			0		=> 'Há menos de 1 minuto',
+			1		=> 'Há %d minute atrás',
+			2		=> 'Há %d minutos atrás',
+			60		=> 'Há 1 hota atrás',
 		),
 		
 		'Sunday'						=> 'domingo',
