@@ -4,7 +4,7 @@
 * mcp [Português]
 *
 * @package language
-* @version 1.0.6
+* @version 1.0.9
 * @Traduzido por: http://phpbbportugal.com - segundo as normas do Acordo Ortográfico
 * @copyright (c) 2005 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
@@ -40,7 +40,7 @@ $lang = array_merge($lang, array(
 	'ACTION'							=> 'Ação',
 	'ACTION_NOTE'						=> 'Ação/Nota',
 	'ADD_FEEDBACK'						=> 'Adicionar relatório',
-	'ADD_FEEDBACK_EXPLAIN'				=> 'Utilize o campo abaixo para escrever o relatório.<br />Não é permitida a utlilização de HTML, BBCode, etc.',
+	'ADD_FEEDBACK_EXPLAIN'				=> 'Utilize o campo abaixo para escrever o relatório. Não é permitida a utlilização de HTML, BBCode, etc.',
 	'ADD_WARNING'						=> 'Adicionar Explicação',
 	'ADD_WARNING_EXPLAIN'				=> 'Pode enviar este aviso para o utilizador em questão com a opção em baixo selecionada. Se acrescentar texto tenha em atenção que HTML, BBCode, etc. não são permitidos.',
 	'ALL_ENTRIES'						=> 'Todas as entradas',
@@ -211,7 +211,7 @@ $lang = array_merge($lang, array(
 	'MCP_WARN_USER'						=> 'Avisar Utilizador',
 
 	'MERGE_POSTS_CONFIRM'				=> 'Deseja fundir as Mensagens selecionadas?',
-	'MERGE_TOPIC_EXPLAIN'				=> 'Use este formulário para fundir Mensagens com Tópicos. Depois de fundidas, as mensagens comportam-se como se tiverem sido enviadas originalmente para o Tópico.<br />Digite a ID do Tópico de destino da mensagem ou clique em <strong>Escolher Tópico</strong> e procure-o na lista.',
+	'MERGE_TOPIC_EXPLAIN'				=> 'Use este formulário para fundir Mensagens com Tópicos. Depois de fundidas, as mensagens comportam-se como se tiverem sido enviadas originalmente para o Tópico.<br />Digite a ID do Tópico de destino da mensagem ou clique em Escolher Tópico e procure-o na lista.',
 	'MERGE_TOPIC_ID'					=> 'ID do Tópico de destino',
 	'MERGE_TOPICS'						=> 'Fundir Tópicos',
 	'MERGE_TOPICS_CONFIRM'				=> 'Tem a certeza que deseja fundir os Tópicos selecionados?',
